==> haskell-prettyprinter-interp-0.2.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-Cgl30uYfsBS8QLN5IvsIyI
key:                  prettyprinter-interp-0.2.0.0-Cgl30uYfsBS8QLN5IvsIyI
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  e95b802bf84dcee3437f3f969f14992a
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-Cgl30uYfsBS8QLN5IvsIyI
depends:
    base-4.16.4.0 prettyprinter-1.7.1-7x8ULV7tlRe3aOwpDSy6yg
    string-interpolate-0.3.4.0-GXJuXmSjC13BzqIiYYesau
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-interp-0.2.0.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-interp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-3YhOpiQhlupBHeZym7lApN
key:                  prettyprinter-interp-0.2.0.0-3YhOpiQhlupBHeZym7lApN
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  9bc374763f359cc6bd076368959a984d
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-3YhOpiQhlupBHeZym7lApN
depends:
    base-4.16.4.0 prettyprinter-1.7.1-EK9br09fdXn8mSlFcoOi40
    string-interpolate-0.3.4.0-AXbHNtRPUlP7gGXvcFQXSp
    template-haskell-2.18.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
